@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.7 2006/12/23 11:11:30 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.7 2006/12/23 11:11:30 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -58,19 +58,12 @@ class SyL_ConfigActions extends SyL_Config
      */
     var $default_priority = 5;
     /**
-     * ܾ󥪥֥
+     * ǡ֥
      * 
      * @access private
      * @var object
      */
-    var $router = null;
-    /**
-     * ܴ֥
-     * 
-     * @access private
-     * @var object
-     */
-    var $lc = null;
+    var $dm = null;
     /**
      * ݡͥȥ᥽åɥ֥
      * 
@@ -100,10 +93,8 @@ class SyL_ConfigActions extends SyL_Config
      */
     function setController(&$controller)
     {
-        $this->controller =& $controller;
-        $this->router     =& $controller->container->getComponent('router');
-        $this->lc         =& $controller->container->getComponent('locationmanager');
-        $this->cm         =& $controller->container->getComponent('componentmethod');
+        $this->dm =& $controller->container->getComponent('datamanager');
+        $this->cm =& $controller->container->getComponent('componentmethod');
     }
 
     /**
@@ -142,11 +133,11 @@ class SyL_ConfigActions extends SyL_Config
 
             // URLǧ
             $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
-            if (preg_match('/^' . $reg . '$/', $this->router->getActionFile(), $matches)) {
+            if (preg_match('/^' . $reg . '$/', $this->dm->getActionFile(), $matches)) {
                 $name = $this->action_key;
-                $this->config[$name]['class']     = $this->router->getClassName();
+                $this->config[$name]['class']     = $this->dm->getClassName();
                 $this->config[$name]['type']      = 'action';
-                $this->config[$name]['file']      = $this->controller->getActionDir() . $this->router->getActionFile();
+                $this->config[$name]['file']      = $this->dm->getActionDir() . $this->dm->getActionFile();
                 $this->config[$name]['reference'] = true;
                 // ¹Խ
                 $this->config[$name]['priority'] = $this->default_priority;
@@ -162,14 +153,14 @@ class SyL_ConfigActions extends SyL_Config
                 for ($i=0; $i<count($matches); $i++) {
                     $template = str_replace("\${$i}", $matches[$i], $template);
                 }
-                $this->lc->setTemplateFile($template);
+                $this->dm->setTemplateFile($template);
 
                 // ӥ塼饹
                 $view_type = isset($attribute['defaultView']) ? $attribute['defaultView'] : 'default';
-                $this->lc->setTemplateType($view_type);
+                $this->dm->setTemplateType($view_type);
                 // ޥӥ塼Ƚ
                 if (strtolower($view_type) == 'customize') {
-                    $this->lc->setCustomizedView($attribute['customizedViewFile'], $attribute['customizedViewClass']);
+                    $this->dm->setCustomizedView($attribute['customizedViewFile'], $attribute['customizedViewClass']);
                 }
             } else {
                 $name = '';
@@ -184,7 +175,7 @@ class SyL_ConfigActions extends SyL_Config
                 if (!isset($this->config[$name]['args'])) {
                     $this->config[$name]['args'] = array();
                 }
-                $method_name = 'method:' . str_replace('{$action}', $this->router->getActionName(), $attribute['name']);
+                $method_name = 'method:' . str_replace('{$action}', $this->dm->getActionName(), $attribute['name']);
                 $this->config[$name]['args'][$method_name] = array();
                 // ٥ȥ
                 $this->config[$name]['event'][$this->event][] = $method_name;
