@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActionscmd.php,v 1.2 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActionscmd.php,v 1.3 2006/12/23 11:11:30 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActionscmd.php,v 1.2 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActionscmd.php,v 1.3 2006/12/23 11:11:30 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActionscmd extends SyL_Config
@@ -57,6 +57,13 @@ class SyL_ConfigActionscmd extends SyL_Config
      * @var string
      */
     var $actioncmd = '';
+    /**
+     * ȥ饪֥
+     * 
+     * @access private
+     * @var object
+     */
+    var $controller = null;
     /**
      * ݡͥȥ᥽åɥ֥
      * 
@@ -86,9 +93,6 @@ class SyL_ConfigActionscmd extends SyL_Config
      */
     function setController(&$controller)
     {
-        $this->controller =& $controller;
-        $this->cm         =& $controller->container->getComponent('componentmethod');
-
         $cmd =& $controller->container->getComponent('cmd');
         $actions = $cmd->getArg();
         $cnt = count($actions);
@@ -96,6 +100,9 @@ class SyL_ConfigActionscmd extends SyL_Config
             trigger_error("[SyL error] Invalid number of Action 0 or 1 ($cnt)", E_USER_ERROR);
         }
         $this->actioncmd = isset($actions[0]) ? $actions[0] : '*';
+
+        $this->controller =& $controller;
+        $this->cm         =& $controller->container->getComponent('componentmethod');
     }
 
     /**
@@ -174,7 +181,6 @@ class SyL_ConfigActionscmd extends SyL_Config
                 break;
 
            case '/actions/action/components/component':
-
                 if (isset($attribute['enable']) && ($attribute['enable'] === 'false')) {
                     $component_name = '';
                     return;
