@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.7 2006/12/23 11:11:30 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.7 2006/12/23 11:11:30 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigFilters extends SyL_Config
@@ -72,12 +72,12 @@ class SyL_ConfigFilters extends SyL_Config
      */
     var $default_priority = 7;
     /**
-     * ܾ󥪥֥
+     * ǡ֥
      * 
      * @access private
      * @var object
      */
-    var $router = null;
+    var $dm = null;
 
     /**
      * 󥹥ȥ饯
@@ -100,8 +100,7 @@ class SyL_ConfigFilters extends SyL_Config
      */
     function setController(&$controller)
     {
-        $this->controller =& $controller;
-        $this->router     =& $controller->container->getComponent('router');
+        $this->dm =& $controller->container->getComponent('datamanager');
     }
 
     /**
@@ -130,7 +129,7 @@ class SyL_ConfigFilters extends SyL_Config
 
             // ̾ǧ
             $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
-            if (preg_match('/^' . $reg . '$/', $this->router->getActionFile())) {
+            if (preg_match('/^' . $reg . '$/', $this->dm->getActionFile())) {
                 $name = '__filter_' . $attribute['name'];
                 $this->config[$name]['class']     = $attribute['class'];
                 $this->config[$name]['type']      = 'filter';
