@@ -27,11 +27,16 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.1 2006/12/19 13:27:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.2 2006/12/23 11:12:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
+/**
+ * ǡ饹
+ */
+require_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';
+
 /**
  * WEBȥ饯饹
  *
@@ -48,7 +53,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.1 2006/12/19 13:27:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.2 2006/12/23 11:12:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerWeb extends SyL_Controller
@@ -74,6 +79,13 @@ class SyL_ControllerWeb extends SyL_Controller
      * @var bool
      */
     var $is_execute_action = true;
+    /**
+     * ǡ饹
+     * 
+     * @access private
+     * @var bool
+     */
+    var $dm = null;
 
     /**
      * 󥹥ȥ饯
@@ -90,6 +102,7 @@ class SyL_ControllerWeb extends SyL_Controller
             trigger_error("[SyL error] Controller parameter action_key not exists", E_USER_ERROR);
         }
 
+        // ƤΥ󥹥ȥ饯
         parent::SyL_Controller($config);
     }
 
