@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.4 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.5 2006/12/23 11:12:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,7 +35,7 @@
 /**
  * ܾ󥯥饹
  */
-require_once SYL_INCLUDE_DIR . '/framework/SyL_Forward.php';
+require_once SYL_INCLUDE_DIR . '/framework/SyL_Router.php';
 
 /**
  * URLѥ᡼ե졼ͤ륯饹
@@ -67,10 +67,10 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Forward.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.4 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.5 2006/12/23 11:12:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
-class SyL_ForwardParameter extends SyL_Forward
+class SyL_RouterParameter extends SyL_Router
 {
     /**
      * ζڤʸ
@@ -78,21 +78,18 @@ class SyL_ForwardParameter extends SyL_Forward
      * @access private
      * @var string
      */
-    var $action_delimiter = SYL_FORWARD_ACTION_DELIMITER;
+    var $action_delimiter = SYL_ROUTER_ACTION_DELIMITER;
 
     /**
      * 󥹥ȥ饯
      *
      * @access public
      */
-    function SyL_ForwardParameter(&$request)
+    function SyL_RouterParameter($pathinfo)
     {
-        // ѥǼѿ
-        $pathinfo = $request->getParameter(SYL_ACTION_KEY);
-
         // ѥå
         if ($this->isInvalidPath($pathinfo)) {
-            SyL_Forward::redirect404();
+            SyL_Response::redirect404();
         }
 
         if ($pathinfo == '') {
@@ -104,7 +101,7 @@ class SyL_ForwardParameter extends SyL_Forward
         } else {
             // ĥȽ
             if ($this->ext && !preg_match('/^(.+)(' . preg_quote($this->url_ext) . ')$/', $pathinfo)) {
-                SyL_Forward::redirect404();
+                SyL_Response::redirect404();
             }
             $pathinfo_file  = basename($pathinfo);
             $pathinfo_dir   = dirname($pathinfo);
