@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.4 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.5 2006/12/23 11:12:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -62,7 +62,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.4 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.5 2006/12/23 11:12:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo extends SyL_Router
@@ -72,7 +72,7 @@ class SyL_RouterPathinfo extends SyL_Router
      *
      * @access public
      */
-    function SyL_RouterPathinfo(&$request)
+    function SyL_RouterPathinfo($action)
     {
         // ١ץȼ
         $script_name = basename($_SERVER['SCRIPT_NAME']);
@@ -81,7 +81,7 @@ class SyL_RouterPathinfo extends SyL_Router
 
         // ѥå
         if ($this->isInvalidPath($pathinfo)) {
-            SyL_Router::redirect404();
+            SyL_Response::redirect404();
         }
 
         if ($pathinfo == '') {
@@ -101,7 +101,7 @@ class SyL_RouterPathinfo extends SyL_Router
                 if (preg_match( '/^(.*)\/(.+)(' . preg_quote($this->url_ext) . ')$/', $pathinfo, $matches)) {
                     $this->action_name = $matches[2];
                 } else {
-                    SyL_Router::redirect404();
+                    SyL_Response::redirect404();
                 }
             } else {
                 $this->action_name = basename($pathinfo);
@@ -109,8 +109,8 @@ class SyL_RouterPathinfo extends SyL_Router
         }
 
         // ֤
-        if ($request->isParameter(SYL_ACTION_KEY)) {
-            $this->action_name = $request->getParameter(SYL_ACTION_KEY);
+        if ($action != null) {
+            $this->action_name = $action;
         }
 
         // PATH_INFO
