@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.4 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.5 2006/12/23 11:12:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -62,7 +62,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.4 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.5 2006/12/23 11:12:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo2 extends SyL_Router
@@ -80,14 +80,14 @@ class SyL_RouterPathinfo2 extends SyL_Router
      *
      * @access public
      */
-    function SyL_RouterPathinfo2(&$request)
+    function SyL_RouterPathinfo2(&$action)
     {
         // PATH_INFOĶѿ
         $pathinfo = isset($_SERVER['PATH_INFO']) ? $_SERVER['PATH_INFO'] : '';
 
         // ѥå
         if ($this->isInvalidPath($pathinfo)) {
-            SyL_Router::redirect404();
+            SyL_Response::redirect404();
         }
 
         if ($pathinfo == '') {
@@ -99,7 +99,7 @@ class SyL_RouterPathinfo2 extends SyL_Router
         } else {
             // ĥȽ
             if ($this->ext && !preg_match('/^(.+)(' . preg_quote($this->url_ext) . ')$/', $pathinfo)) {
-                SyL_Router::redirect404();
+                SyL_Response::redirect404();
             }
             $pathinfo_file  = basename($pathinfo);
             $pathinfo_dir   = dirname($pathinfo);
@@ -135,8 +135,8 @@ class SyL_RouterPathinfo2 extends SyL_Router
         }
 
         // ֤
-        if ($request->isParameter(SYL_ACTION_KEY)) {
-            $this->action_name = $request->getParameter(SYL_ACTION_KEY);
+        if ($action != null) {
+            $this->action_name = $action;
         }
 
         // PATH_INFO
