@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.7 2006/12/23 11:12:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -74,7 +74,7 @@ define('SYL_CONFIG_CONTROLLER_NAME', 'controller');
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.7 2006/12/23 11:12:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -182,7 +182,7 @@ class SyL_Controller
         define('SYL_APP_DIR', SYL_WEBAPP_DIR . '/app/' . $config['app_name']);
 
         // ɤ߹
-        SyL_DefinesReader::readConfig($this, $this->defines_file_name);
+        SyL_DefinesReader::readConfig($this->defines_file_name);
 
         // shutdownϥɥ
         if ($this->destory_method != '') {
