@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DefinesReader.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DefinesReader.php,v 1.7 2006/12/23 11:12:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Cache.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DefinesReader.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DefinesReader.php,v 1.7 2006/12/23 11:12:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DefinesReader
@@ -61,7 +61,7 @@ class SyL_DefinesReader
      * @param object ȥ饪֥
      * @param string ե̾
      */
-    function readConfig(&$controller, $defines_file_name)
+    function readConfig($defines_file_name)
     {
         // ץꥱͤɤ߹
         $config_file1 = SYL_APP_DIR . "/{$defines_file_name}";
@@ -76,14 +76,14 @@ class SyL_DefinesReader
             $config = $cache->read(array($config_file1, $config_file2));
             if (!$config) {
                 $config = array();
-                $config += SyL_DefinesReader::readConfigFile($config_file1, $controller);
-                $config += SyL_DefinesReader::readConfigFile($config_file2, $controller);
+                $config += SyL_DefinesReader::readConfigFile($config_file1);
+                $config += SyL_DefinesReader::readConfigFile($config_file2);
                 $cache->write($config);
             }
         } else {
             // åѤʤ
-            $config += SyL_DefinesReader::readConfigFile($config_file1, $controller);
-            $config += SyL_DefinesReader::readConfigFile($config_file2, $controller);
+            $config += SyL_DefinesReader::readConfigFile($config_file1);
+            $config += SyL_DefinesReader::readConfigFile($config_file2);
         }
 
         // ɤ߹
@@ -98,9 +98,10 @@ class SyL_DefinesReader
      * @param string ե̾
      * @param object ȥ饪֥
      */
-    function readConfigFile($config_file, &$controller)
+    function readConfigFile($config_file)
     {
         if (is_file($config_file)) {
+            $controller = null; // ߡ
             $config =& SyL_Config::getObject('defines', $config_file, $controller);
             $config->parseXML();
             return $config->getConfig();
