@@ -27,16 +27,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.7 2006/12/23 11:12:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-/**
- * 饹
- */
-require_once SYL_INCLUDE_DIR . '/framework/SyL_Loggers.php';
-
 /**
  * 顼饹
  *
@@ -44,7 +39,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loggers.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.7 2006/12/23 11:12:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -231,7 +226,7 @@ class SyL_Error
      */
     function logging($error_no, $error_message)
     {
-        if (class_exists('SyL_Loggers') && ($error_no <= SYL_DEBUG)) {
+        if ($error_no <= SYL_DEBUG) {
             $log_string  = '[' . $this->getErrorType($error_no) . '] ' . $error_message . $this->eof;
             foreach ($this->getTrace() as $value) {
                 $log_string .= "[file] "     . $value['file'] . " ";
