@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.4 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.5 2006/12/23 11:12:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.4 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.5 2006/12/23 11:12:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
@@ -101,20 +101,30 @@ class SyL_Router
      */
     var $class_name = '';
 
+    /**
+     * 󥹥ȥ饯
+     *
+     * @access public
+     * @param object ꥯȥ֥
+     */
+    function SyL_Router($action)
+    {
+    }
+
     /**
      * եɥ롼
      *
      * @static
      * @access public
-     * @param object ꥯȥ֥
+     * @param object ǡ֥
      * @param string 襪֥̾
      * @return object 襪֥
      */
-    function &getObject(&$requests, $rule)
+    function &getObject(&$request, $rule)
     {
         $class_name = 'SyL_Router' . ucfirst($rule);
         include_once SYL_INCLUDE_DIR . "/framework/Router/{$class_name}.php";
-        $obj =& new $class_name($requests->getParameterObject());
+        $obj =& new $class_name($request->getParameter(SYL_ACTION_KEY));
         return $obj;
     }
 
@@ -170,7 +180,7 @@ class SyL_Router
      */
     function setSyLSelf($syl_self)
     {
-        define('SYL_SELF', $syl_self);
+        //define('SYL_SELF', $syl_self);
     }
 
     /**
@@ -184,28 +194,6 @@ class SyL_Router
     {
         return preg_match('/\.\.\//', preg_quote($pathinfo, '/'));
     }
-
-    /**
-     * 404 Not Found ˥쥯Ȥ
-     *
-     * @access public
-     * @param string URL
-     */
-    function redirect404()
-    {
-        $request_uri = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '';
-        SyL_Loggers::info("[Router] 404 Not Found - {$request_uri}");
-
-        header("HTTP/1.0 404 Not Found");
-        if (defined('SYL_ROUTER_URL_404') && SYL_ROUTER_URL_404) {
-            header('Location: ' . SYL_ROUTER_URL_404);
-            exit;
-        } else {
-            exit("<h2>HTTP/1.0 404 Not Found</h2>");
-        }
-    }
-
-
 }
 
 ?>
