@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewDefault.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewDefault.php,v 1.7 2006/12/23 11:12:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_View.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewDefault.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewDefault.php,v 1.7 2006/12/23 11:12:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewDefault extends SyL_View
@@ -54,31 +54,36 @@ class SyL_ViewDefault extends SyL_View
      *
      * @access public
      */
-    function SyL_ViewDefault(&$lm, &$cm)
+    function SyL_ViewDefault(&$dm, &$cm)
     {
-        parent::SyL_View($lm, $cm);
+        parent::SyL_View($dm, $cm);
     }
 
     /**
-     * ƥץ졼ɽ
+     * HTML󥰼¹
      * 
      * @access public
      */
     function render()
     {
         // 󤫤Υѥ᡼
-        foreach ($this->lm->getValues() as $key => $value) {
-            if (is_object($value)) {
-                $$key =& $value;
+        $values =& $this->getActionValues();
+        foreach (array_keys($values) as $key) {
+            if (is_object($values[$key])) {
+                $$key =& $values[$key];
             } else {
-                $$key = $value;
+                $$key = $values[$key];
             }
         }
 
         // ƥץ졼ȼ
-        $template_file = $this->lm->getTemplateDir() . $this->lm->getTemplateFile();
-        // ӥ塼ɽ
+        $template_file = $this->getTemplateDir() . $this->getTemplateFile();
+
+        // ɽƤ򥻥å
+        ob_start();
         include_once $template_file;
+        $this->setRender(ob_get_contents());
+        ob_end_clean();
     }
 }
 
