@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.7 2006/12/23 11:12:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_View.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.7 2006/12/23 11:12:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewSmarty extends SyL_View
@@ -65,9 +65,9 @@ class SyL_ViewSmarty extends SyL_View
      *
      * @access public
      */
-    function SyL_ViewSmarty(&$lm, &$cm)
+    function SyL_ViewSmarty(&$dm, &$cm)
     {
-        parent::SyL_View($lm, $cm);
+        parent::SyL_View($dm, $cm);
 
         $this->smarty =& new Smarty();
         $this->smarty->compile_dir = SYL_SMARTY_COMPILE_DIR;
@@ -76,23 +76,29 @@ class SyL_ViewSmarty extends SyL_View
     }
 
     /**
-     * ƥץ졼ɽ
+     * HTML󥰼¹
      * 
      * @access public
      */
     function render()
     {
         // ƥץ졼ȥǥ쥯ȥꥻå
-        $this->smarty->template_dir = $this->lm->getTemplateDir();
+        $this->smarty->template_dir = $this->getTemplateDir();
+
         // 󤫤Υѥ᡼
-        foreach ($this->lm->getValues() as $key => $value) {
-            if (is_object($value)) {
-                $this->smarty->assign_by_ref($key, $value);
+        $values =& $this->getActionValues();
+        foreach (array_keys($values) as $key) {
+            if (is_object($values[$key])) {
+                $this->smarty->assign_by_ref($key, $values[$key]);
             } else {
-                $this->smarty->assign($key, $value);
+                $this->smarty->assign($key, $values[$key]);
             }
         }
-        $this->smarty->display($this->lm->getTemplateFile());
+
+        //$this->smarty->display($this->getTemplateFile());
+
+        // ɽƤ򥻥å
+        $this->setRender($this->smarty->fetch($this->getTemplateFile()));
     }
 }
 
