@@ -20,7 +20,7 @@ class {SYL_CLASS}
      * @param object ꥯȥ֥
      * @param object ݡͥȥ᥽åɥ֥
      */
-    function execute(&$requests, &$cm)
+    function execute(&$request, &$cm)
     {
     }
 
